// BHOCOP Version 1.0
// Copyright (c) 2001 Ziff Davis Media, Inc.
// All rights reserved.
// First Published in PC Magazine, US Edition, May 22, 2001.
// Programmer: Patrick Philippot

#include "stdafx.h"
#include "BHOCop.h"
#include "SaveConfigDlg.h"
#include "BHOCopDlg.h"
#include "StringExt.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CSaveConfigDlg dialog


CSaveConfigDlg::CSaveConfigDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CSaveConfigDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CSaveConfigDlg)
	//}}AFX_DATA_INIT
}


void CSaveConfigDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CSaveConfigDlg)
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CSaveConfigDlg, CDialog)
	//{{AFX_MSG_MAP(CSaveConfigDlg)
	ON_BN_CLICKED(IDC_DELETE, OnDelete)
	ON_CBN_EDITCHANGE(IDC_CFGNAME, OnEditChangeCfgName)
	ON_CBN_SELCHANGE(IDC_CFGNAME, OnSelChangeCfgName)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSaveConfigDlg message handlers

BOOL CSaveConfigDlg::OnInitDialog() 
{
	CDialog::OnInitDialog();

	m_CfgName.SubclassDlgItem(IDC_CFGNAME, this);

	if (!m_sCurrentName.IsEmpty() && !m_sIniFilename.IsEmpty())
	{
		TCHAR szBuffer[2048];

		// Get list of entries
		GetPrivateProfileString(CBHOCopDlg::g_szIniCfgSection, NULL, _T(""), szBuffer, sizeof(szBuffer), m_sIniFilename);
		
		TCHAR	szCfgName[MAX_PATH];
		TCHAR*	lpCfgName = szBuffer;

		// For each entry, get Config name and add entry to combo box
		while (*lpCfgName != (TCHAR) '\0')
		{
			_tcscpy(szCfgName, lpCfgName);
			lpCfgName += _tcslen(szCfgName) + 1;
			m_CfgName.AddString(szCfgName);
		}

		// Now select current config
		int nIndex = m_CfgName.FindString(0, m_sCurrentName);
		if (nIndex != CB_ERR)
		{
			m_CfgName.SetCurSel(nIndex);
			// Can't delete current configuration
			GetDlgItem(IDC_DELETE)->EnableWindow(FALSE);
		}
	}
	
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

void CSaveConfigDlg::OnOK() 
{
	m_CfgName.GetWindowText(m_sCurrentName);

	CDialog::OnOK();
}

void CSaveConfigDlg::OnDelete() 
{
	// Delete selected configuration
	CStringEx sCfgToDelete;

	m_CfgName.GetWindowText(sCfgToDelete);
	if (!sCfgToDelete.IsEmpty() && !m_sIniFilename.IsEmpty())
	{
		int nIndex = m_CfgName.FindStringExact(-1, sCfgToDelete);
		if (nIndex != -1)
		{
			// Delete related information in INI file
			WritePrivateProfileString(sCfgToDelete, NULL, NULL, m_sIniFilename);
			WritePrivateProfileString(CBHOCopDlg::g_szIniCfgSection, sCfgToDelete, NULL, m_sIniFilename);
			m_CfgName.DeleteString(nIndex);
			if (m_CfgName.GetCount() != 0)
			{
				m_CfgName.SetCurSel(0);
				OnSelChangeCfgName();	
				// Because the selection changed event is not 
				// automatically triggered if there's only one 
				// item in the list.
			}
		}
	}
}

void CSaveConfigDlg::OnEditChangeCfgName() 
{
	// Manage state of Delete button
	CString sCfgToDelete;

	m_CfgName.GetWindowText(sCfgToDelete);
	if (!sCfgToDelete.IsEmpty() && (sCfgToDelete.CompareNoCase(m_sCurrentName) != 0))
	{
		int nIndex = m_CfgName.FindStringExact(-1, sCfgToDelete);
		GetDlgItem(IDC_DELETE)->EnableWindow(nIndex != -1);
	}
	else
		GetDlgItem(IDC_DELETE)->EnableWindow(FALSE);
}

void CSaveConfigDlg::OnSelChangeCfgName() 
{
	// Manage state of Delete button
	int nIndex = m_CfgName.GetCurSel();
	
	BOOL bCanDelete = nIndex != -1;

	if (bCanDelete)
	{
		CString sCfgToDelete;

		m_CfgName.GetLBText(nIndex, sCfgToDelete);
		bCanDelete = bCanDelete && (sCfgToDelete.CompareNoCase(m_sCurrentName) != 0);
	}

	GetDlgItem(IDC_DELETE)->EnableWindow(bCanDelete);
}

/////////////////////////////////////////////////////////////////////////////
// CNameCombo

CNameCombo::CNameCombo()
{
}

CNameCombo::~CNameCombo()
{
}


BEGIN_MESSAGE_MAP(CNameCombo, CComboBox)
	//{{AFX_MSG_MAP(CNameCombo)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CNameCombo message handlers

BOOL CNameCombo::PreTranslateMessage(MSG* pMsg) 
{
	if (pMsg->message == WM_CHAR)
	{
		char ch = (char) pMsg->wParam;
		if (!isalnum(ch) && !isspace(ch) && !iscntrl(ch)) 
			return 1;
		else
			return CComboBox::PreTranslateMessage(pMsg);
	}
	else
		return CComboBox::PreTranslateMessage(pMsg);
}

